[Lldb-commits] [lldb] r151587 - /lldb/trunk/test/functionalities/memory/read/TestMemoryRead.py

Johnny Chen johnny.chen at apple.com
Mon Feb 27 15:27:16 PST 2012


Author: johnny
Date: Mon Feb 27 17:27:16 2012
New Revision: 151587

URL: http://llvm.org/viewvc/llvm-project?rev=151587&view=rev
Log:
Modify the expected error message accordingly after the recent change to DataExtractor.cpp.

Modified:
    lldb/trunk/test/functionalities/memory/read/TestMemoryRead.py

Modified: lldb/trunk/test/functionalities/memory/read/TestMemoryRead.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/memory/read/TestMemoryRead.py?rev=151587&r1=151586&r2=151587&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/memory/read/TestMemoryRead.py (original)
+++ lldb/trunk/test/functionalities/memory/read/TestMemoryRead.py Mon Feb 27 17:27:16 2012
@@ -86,9 +86,9 @@
             substrs = ['abcdefg'])
 
         # (lldb) memory read --format 'hex float' --size 16 `&argc`
         # 0x7fff5fbff9a0: unsupported hex float byte size 16
         self.expect("memory read --format 'hex float' --size 16 `&argc`",
-            substrs = ['unsupported hex float byte size'])
+            substrs = ['unsupported byte size (16) for hex float format'])
 
 
 if __name__ == '__main__':
@@ -86,9 +86,9 @@
 
         # (lldb) memory read --format 'hex float' --size 16 `&argc`
-        # 0x7fff5fbff9a0: unsupported hex float byte size 16
+        # 0x7fff5fbff5b0: error: unsupported byte size (16) for hex float format
         self.expect("memory read --format 'hex float' --size 16 `&argc`",





More information about the lldb-commits mailing list